<?php
// $Revision: 1.1.4.1.2.17 $
// ------------------------------------------------------------------------- //
//  XooNIps - Neuroinformatics Base Platform System                          //
//  Copyright (C) 2005-2008 RIKEN, Japan All rights reserved.                //
//  http://xoonips.sourceforge.jp/                                           //
// ------------------------------------------------------------------------- //
//  This program is free software; you can redistribute it and/or modify     //
//  it under the terms of the GNU General Public License as published by     //
//  the Free Software Foundation; either version 2 of the License, or        //
//  (at your option) any later version.                                      //
//                                                                           //
//  You may not change or alter any portion of this comment or credits       //
//  of supporting developers from this source code or any supporting         //
//  source code which is considered copyrighted (c) material of the          //
//  original comment or credit authors.                                      //
//                                                                           //
//  This program is distributed in the hope that it will be useful,          //
//  but WITHOUT ANY WARRANTY; without even the implied warranty of           //
//  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the            //
//  GNU General Public License for more details.                             //
//                                                                           //
//  You should have received a copy of the GNU General Public License        //
//  along with this program; if not, write to the Free Software              //
//  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307 USA //
// ------------------------------------------------------------------------- //

// _AM_<MODULENAME>_<STRINGNAME>

// labels
define( '_AM_XOONIPS_LABEL_ADD', 'ADD' );
define( '_AM_XOONIPS_LABEL_UPDATE', 'UPDATE' );
define( '_AM_XOONIPS_LABEL_MODIFY', 'MODIFY' );
define( '_AM_XOONIPS_LABEL_PREFERENCES', 'PREFERENCES' );
define( '_AM_XOONIPS_LABEL_DELETE', 'DELETE' );
define( '_AM_XOONIPS_LABEL_REGISTER', 'REGISTER' );
define( '_AM_XOONIPS_LABEL_NEXT', 'NEXT' );
define( '_AM_XOONIPS_LABEL_BACK', 'BACK' );
define( '_AM_XOONIPS_LABEL_DOWNLOAD', 'DOWNLOAD' );
define( '_AM_XOONIPS_LABEL_UPLOAD', 'UPLOAD' );
define( '_AM_XOONIPS_LABEL_CLEAR', 'CLEAR' );
define( '_AM_XOONIPS_LABEL_CANCEL', 'CANCEL' );
define( '_AM_XOONIPS_LABEL_EXECUTE', 'EXECUTE' );
define( '_AM_XOONIPS_LABEL_REQUIRED', 'Required' );
define( '_AM_XOONIPS_LABEL_OPTIONAL', 'Optional' );
define( '_AM_XOONIPS_LABEL_YES', 'YES' );
define( '_AM_XOONIPS_LABEL_NO', 'NO' );
define( '_AM_XOONIPS_LABEL_UP', 'UP' );
define( '_AM_XOONIPS_LABEL_DOWN', 'DOWN' );
define( '_AM_XOONIPS_LABEL_DATE', 'Date/Time' );
define( '_AM_XOONIPS_LABEL_URL', 'URL' );
define( '_AM_XOONIPS_LABEL_WEIGHT', 'Weight' );
define( '_AM_XOONIPS_LABEL_ACTION', 'Action' );
define( '_AM_XOONIPS_LABEL_VISIBLE', 'Visible' );
define( '_AM_XOONIPS_LABEL_SORT', 'Sort' );
define( '_AM_XOONIPS_LABEL_MODULENAME', 'Module Name' );
define( '_AM_XOONIPS_LABEL_UID', 'UID' );
define( '_AM_XOONIPS_LABEL_UNAME', 'User Name' );
define( '_AM_XOONIPS_LABEL_NAME', 'Real Name' );
define( '_AM_XOONIPS_LABEL_EMAIL', 'E-Mail' );
define( '_AM_XOONIPS_LABEL_POSITION', 'Position' );
define( '_AM_XOONIPS_LABEL_DIVISION', 'Division' );
define( '_AM_XOONIPS_LABEL_COMPANY_NAME', 'Company Name' );
define( '_AM_XOONIPS_LABEL_TEL', 'Phone Number' );
define( '_AM_XOONIPS_LABEL_FAX', 'FAX Number' );
define( '_AM_XOONIPS_LABEL_ADDRESS', 'Address' );
define( '_AM_XOONIPS_LABEL_COUNTRY', 'Country' );
define( '_AM_XOONIPS_LABEL_ZIPCODE', 'Zipcode' );
define( '_AM_XOONIPS_LABEL_APPEAL', 'Free Description' );
define( '_AM_XOONIPS_LABEL_NOTICE_MAIL', 'New Item Mail Notification (par days)' );
define( '_AM_XOONIPS_LABEL_PRIVATE', 'Private Area' );
define( '_AM_XOONIPS_LABEL_ITEM_NUMBER_LIMIT', 'Maximum number of Items' );
define( '_AM_XOONIPS_LABEL_INDEX_NUMBER_LIMIT', 'Maximum number of Indexes' );
define( '_AM_XOONIPS_LABEL_ITEM_STORAGE_LIMIT', 'Maximum Storage size [MB]' );
define( '_AM_XOONIPS_LABEL_PRIVATE_ITEM_NUMBER_LIMIT', 'Maximum Private Items' );
define( '_AM_XOONIPS_LABEL_PRIVATE_INDEX_NUMBER_LIMIT', 'Maximum Private Indexes' );
define( '_AM_XOONIPS_LABEL_PRIVATE_ITEM_STORAGE_LIMIT', 'Maximum Disk Space for Private Items [MB]' );
define( '_AM_XOONIPS_LABEL_REQUIRED_MARK', '<span style="font-weight: bold; color: red;">*</span>' );
define( '_AM_XOONIPS_LABEL_ITEM_ID', 'Item ID' );
define( '_AM_XOONIPS_LABEL_ITEM_TYPE', 'Item Type' );
define( '_AM_XOONIPS_LABEL_ITEM_TITLE', 'Title' );

// messages
define( '_AM_XOONIPS_MSG_EXECUTE_CONFIRM', 'Do you really want to execute this?' );
define( '_AM_XOONIPS_MSG_DELETE_CONFIRM', 'Do you really want to delete?' );
define( '_AM_XOONIPS_MSG_REGISTER_CONFIRM', 'Do you really want to register?' );
define( '_AM_XOONIPS_MSG_EMPTY', 'No Records found' );
define( '_AM_XOONIPS_MSG_DBUPDATED', 'Database has been updated' );
define( '_AM_XOONIPS_MSG_ILLACCESS', 'Illegal Access' );
define( '_AM_XOONIPS_MSG_UNEXPECTED_ERROR', 'Unexpected error occurred' );
define( '_AM_XOONIPS_MSG_PASSWORD_MISMATCH', 'Both passwords are different. They must be identical.' );
// unsupported
define( '_AM_XOONIPS_UNSUPPORTED_DELUSER', 'Sorry, the Delete User is not supported on this version of XooNIps.<br />This feature is will be supported by next relase. Please wait for future release.' );

// main title
define( '_AM_XOONIPS_TITLE', 'XooNIps Configurations' );

// sub titles
define( '_AM_XOONIPS_SYSTEM_TITLE', 'System Configuration' );
define( '_AM_XOONIPS_SYSTEM_DESC', 'System configuration for the XooNIps. The system administrator will change these settins.' );
define( '_AM_XOONIPS_POLICY_TITLE', 'Site Policies' );
define( '_AM_XOONIPS_POLICY_DESC', 'Configurations for the Site Policies. The site manager have to decide these policies before using XooNIps.' );
define( '_AM_XOONIPS_MAINTENANCE_TITLE', 'Maintenance' );
define( '_AM_XOONIPS_MAINTENANCE_DESC', 'There are various operations related to XooNIps database maintenance.' );

// system configurations
define( '_AM_XOONIPS_SYSTEM_BASIC_TITLE', 'Basic Configurations' );
define( '_AM_XOONIPS_SYSTEM_BASIC_DESC', 'The XooNIps is required to work at least these settings.' );
define( '_AM_XOONIPS_SYSTEM_TREE_TITLE', 'Inline Frame' );
define( '_AM_XOONIPS_SYSTEM_TREE_DESC', 'Settings for the width and height of inline frame in the Index-Tree block.' );
define( '_AM_XOONIPS_SYSTEM_RSS_TITLE', 'RSS Feeds' );
define( '_AM_XOONIPS_SYSTEM_RSS_DESC', 'Settings for the RSS feeds.' );
define( '_AM_XOONIPS_SYSTEM_PRINT_TITLE', 'Printer Friendly' );
define( '_AM_XOONIPS_SYSTEM_PRINT_DESC', 'Settings for the printer-friendly pages.' );
define( '_AM_XOONIPS_SYSTEM_OAIPMH_TITLE', 'OAI-PMH' );
define( '_AM_XOONIPS_SYSTEM_OAIPMH_DESC', 'Configurations for OAI-PMH Repository and Harvester.' );
define( '_AM_XOONIPS_SYSTEM_PROXY_TITLE', 'Proxy' );
define( '_AM_XOONIPS_SYSTEM_PROXY_DESC', 'Configurations for the proxy server.' );
define( '_AM_XOONIPS_SYSTEM_MODULE_TITLE', 'Notifications' );
define( '_AM_XOONIPS_SYSTEM_MODULE_DESC', 'Configurations for the event notifications' );
//define( '_AM_XOONIPS_SYSTEM_MODULE_TITLE', 'Preferences' );
//define( '_AM_XOONIPS_SYSTEM_MODULE_DESC', 'Optional settings for the XOOPS integrated functions.' );
define( '_AM_XOONIPS_SYSTEM_XOOPS_TITLE', 'XOOPS Extension' );
define( '_AM_XOONIPS_SYSTEM_XOOPS_DESC', 'XooNIps operates extending the information of XOOPS. In here, it configurates in order to utilize the information of XOOPS with XooNIps.' );
define( '_AM_XOONIPS_SYSTEM_CHECK_TITLE', 'Configuraion Test' );
define( '_AM_XOONIPS_SYSTEM_CHECK_DESC', 'Configuration test for XooNIps requirements environment.' );
// >> basic configurations
define( '_AM_XOONIPS_SYSTEM_BASIC_MODERATOR_GROUP_TITLE', 'Moderator Group' );
define( '_AM_XOONIPS_SYSTEM_BASIC_MODERATOR_GROUP_DESC', 'Choose the XOOPS group for the XooNIps moderators.' );
define( '_AM_XOONIPS_SYSTEM_BASIC_UPLOAD_DIR_TITLE', 'File Upload Directory' );
define( '_AM_XOONIPS_SYSTEM_BASIC_UPLOAD_DIR_DESC', 'Enter absolute path for the file upload direcotry. This direcotry needs write permission for the web server process.' );
define( '_AM_XOONIPS_SYSTEM_BASIC_MAGIC_FILE_PATH_TITLE', 'Magic File Path' );
define( '_AM_XOONIPS_SYSTEM_BASIC_MAGIC_FILE_PATH_DESC', 'Enter absolute path of magic file used to get mime-type of a file. Extension \'.mime\' is not needed.' );
// >> tree block configuration
define( '_AM_XOONIPS_SYSTEM_TREE_TREE_FRAME_WIDTH_TITLE', 'Width of index-tree block' );
define( '_AM_XOONIPS_SYSTEM_TREE_TREE_FRAME_WIDTH_DESC', 'Enter width for the inline-frame in the index-tree block.' );
define( '_AM_XOONIPS_SYSTEM_TREE_TREE_FRAME_HEIGHT_TITLE', 'Height of index-tree block' );
define( '_AM_XOONIPS_SYSTEM_TREE_TREE_FRAME_HEIGHT_DESC', 'Enter height for the inline-frame in the index-tree block.' );
// >> rss file configuration
define( '_AM_XOONIPS_SYSTEM_RSS_FEED_URL_TITLE', 'Feed Url' );
define( '_AM_XOONIPS_SYSTEM_RSS_FEED_URL_DESC', 'RSS 1.0, RSS 2.0 and Atom 1.0 feed types are supported on XooNIps.<br />You can use these feed urls for item and group updating announcements.' );
define( '_AM_XOONIPS_SYSTEM_RSS_FEED_ITEM_MAX_TITLE', 'Maximum number of Feeds' );
define( '_AM_XOONIPS_SYSTEM_RSS_FEED_ITEM_MAX_DESC', 'Enter maximum number of RSS feeds. This value must be greater than or equal zero.' );
// >> printer priendly configuration
define( '_AM_XOONIPS_SYSTEM_PRINT_PRINTER_FRIENDLY_HEADER_TITLE', 'Page Header' );
define( '_AM_XOONIPS_SYSTEM_PRINT_PRINTER_FRIENDLY_HEADER_DESC', 'Enter page header for printer-friendly pages which can use HTML.');
// >> oai-pmh configuration
define( '_AM_XOONIPS_SYSTEM_OAIPMH_REPOSITORY_TITLE', 'Repository Configurations' );
define( '_AM_XOONIPS_SYSTEM_OAIPMH_HARVESTER_TITLE', 'Hervester Configurations' );
define( '_AM_XOONIPS_SYSTEM_OAIPMH_REPOSITORY_INSTITUTION_TITLE', '&lt;institution&gt; variable' );
define( '_AM_XOONIPS_SYSTEM_OAIPMH_REPOSITORY_INSTITUTION_DESC', '' );
define( '_AM_XOONIPS_SYSTEM_OAIPMH_REPOSITORY_PUBLISHER_TITLE', '&lt;publisher&gt; variable' );
define( '_AM_XOONIPS_SYSTEM_OAIPMH_REPOSITORY_PUBLISHER_DESC', '' );
define( '_AM_XOONIPS_SYSTEM_OAIPMH_REPOSITORY_NAME_TITLE', 'Repository Name' );
define( '_AM_XOONIPS_SYSTEM_OAIPMH_REPOSITORY_NAME_DESC', '' );
define( '_AM_XOONIPS_SYSTEM_OAIPMH_REPOSITORY_NIJC_CODE_TITLE', 'Database ID' );
define( '_AM_XOONIPS_SYSTEM_OAIPMH_REPOSITORY_NIJC_CODE_DESC', '' );
define( '_AM_XOONIPS_SYSTEM_OAIPMH_REPOSITORY_DELETION_TRACK_TITLE', 'Number of days tracking item deletion.' );
define( '_AM_XOONIPS_SYSTEM_OAIPMH_REPOSITORY_DELETION_TRACK_DESC', '' );
define( '_AM_XOONIPS_SYSTEM_OAIPMH_HARVESTER_REPOSITORIES_TITLE', 'Repositories which to harvest' );
define( '_AM_XOONIPS_SYSTEM_OAIPMH_HARVESTER_REPOSITORIES_DESC', 'Enter repository URLs per line. A line beginning with a <strong>;</strong> (semicolon) character is treated as a remark and will not be used by the XooNIps' );
// >> proxy configuration
define( '_AM_XOONIPS_SYSTEM_PROXY_PROXY_HOST_TITLE', 'Host' );
define( '_AM_XOONIPS_SYSTEM_PROXY_PROXY_HOST_DESC', 'Enter the appropriate host name or IP address of the proxy server.' );
define( '_AM_XOONIPS_SYSTEM_PROXY_PROXY_PORT_TITLE', 'Port' );
define( '_AM_XOONIPS_SYSTEM_PROXY_PROXY_PORT_DESC', 'Enter the appropriate port number of the proxy server.' );
define( '_AM_XOONIPS_SYSTEM_PROXY_PROXY_USER_TITLE', 'User Name' );
define( '_AM_XOONIPS_SYSTEM_PROXY_PROXY_USER_DESC', 'Enter the user name, if required to authenticate the proxy server.' );
define( '_AM_XOONIPS_SYSTEM_PROXY_PROXY_PASS_TITLE', 'Password' );
define( '_AM_XOONIPS_SYSTEM_PROXY_PROXY_PASS_DESC', 'Enter the password for the authentication.' );
// >> XOOPS extension
define( '_AM_XOONIPS_SYSTEM_XOOPS_USERADD_TITLE', 'XOOPS User Pickup' );
define( '_AM_XOONIPS_SYSTEM_XOOPS_USERADD_DESC', 'Register existing XOOPS user which is not registered yet to the XooNIps system' );
define( '_AM_XOONIPS_SYSTEM_XOOPS_USERADD_MSG_EMPTY', 'No users found. Everyone already registered in the XooNIps system.' );
define( '_AM_XOONIPS_SYSTEM_XOOPS_ZOMBIELIST_TITLE', 'Repair XooNIps User Information' );
define( '_AM_XOONIPS_SYSTEM_XOOPS_ZOMBIELIST_DESC', 'Delete broken user which is only deleted by XOOPS user function' );
define( '_AM_XOONIPS_SYSTEM_XOOPS_ZOMBIELIST_LABEL_ITEMCOUNT', 'Registered Items (Group/Public)' );
define( '_AM_XOONIPS_SYSTEM_XOOPS_ZOMBIELIST_MSG_EMPTY', 'No broken users found' );
define( '_AM_XOONIPS_SYSTEM_XOOPS_ITEM_RESCUE_TITLE', 'Rescue Items' );
define( '_AM_XOONIPS_SYSTEM_XOOPS_ITEM_RESCUE_DESC', 'Selected user still has Public and/or Group items.<br />Choice user and index for transfering these items.' );
define( '_AM_XOONIPS_SYSTEM_XOOPS_ITEM_RESCUE_LABEL_FROM', 'From' );
define( '_AM_XOONIPS_SYSTEM_XOOPS_ITEM_RESCUE_LABEL_TO', 'To' );
define( '_AM_XOONIPS_SYSTEM_XOOPS_ZOMBIE_DELETE_MSG_REDIRECT', 'Please rescue registered items before user deleting.' );
// >> configuration check
define( '_AM_XOONIPS_SYSTEM_CHECK_FORM_TITLE', 'Check results' );
define( '_AM_XOONIPS_SYSTEM_CHECK_LABEL_CHECK', 'TEST' );
define( '_AM_XOONIPS_SYSTEM_CHECK_LABEL_RECHECK', 'Test Again' );
define( '_AM_XOONIPS_SYSTEM_CHECK_LABEL_OK', 'OK' );
define( '_AM_XOONIPS_SYSTEM_CHECK_LABEL_NOTICE', 'Notice' );
define( '_AM_XOONIPS_SYSTEM_CHECK_LABEL_FAIL', 'Fail' );
define( '_AM_XOONIPS_SYSTEM_CHECK_LABEL_ENABLE', 'Enable' );
define( '_AM_XOONIPS_SYSTEM_CHECK_LABEL_DISABLE', 'Disable' );
define( '_AM_XOONIPS_SYSTEM_CHECK_LABEL_RESULTS', 'Total Result' );
define( '_AM_XOONIPS_SYSTEM_CHECK_CATEGORY_PHPINI', 'php.ini' );
define( '_AM_XOONIPS_SYSTEM_CHECK_CATEGORY_PHPEXT', 'PHP extensions' );
define( '_AM_XOONIPS_SYSTEM_CHECK_CATEGORY_MYSQL', 'MySQL character set' );
define( '_AM_XOONIPS_SYSTEM_CHECK_CATEGORY_COMMAND', 'External programs' );
define( '_AM_XOONIPS_SYSTEM_CHECK_CATEGORY_XOONIPS', 'XooNIps configurations' );
define( '_AM_XOONIPS_SYSTEM_CHECK_MSG_PHP', 'Please check PHP configuration' );
define( '_AM_XOONIPS_SYSTEM_CHECK_MSG_MYSQL', 'Please check MySQL configuration' );
define( '_AM_XOONIPS_SYSTEM_CHECK_MSG_COMMAND', 'Please check external programs' );
define( '_AM_XOONIPS_SYSTEM_CHECK_MSG_XOONIPS', 'Please check XooNIps configuration' );

// site policy settings
define( '_AM_XOONIPS_POLICY_ACCOUNT_TITLE', 'User Information' );
define( '_AM_XOONIPS_POLICY_ACCOUNT_DESC', 'Policy settings for the user informations.' );
define( '_AM_XOONIPS_POLICY_GROUP_TITLE', 'Group Information' );
define( '_AM_XOONIPS_POLICY_GROUP_DESC', 'Policy settings for the group informatins.' );
define( '_AM_XOONIPS_POLICY_ITEM_TITLE', 'Item Information' );
define( '_AM_XOONIPS_POLICY_ITEM_DESC', 'Policy settings for the item information.' );
define( '_AM_XOONIPS_POLICY_MODERATOR_TITLE', 'Moderators Privileges' );
define( '_AM_XOONIPS_POLICY_MODERATOR_DESC', 'Policy settings for the moderators privileges.' );
define( '_AM_XOONIPS_POLICY_POSITION_TITLE', 'Positions' );
define( '_AM_XOONIPS_POLICY_POSITION_DESC', 'Configuration for the member\'s positions. If negative value is entered in \'Weight\' field then the position will disappear from the \'User List\' view.' );
define( '_AM_XOONIPS_POLICY_RANKING_TITLE', 'Rankings' );
define( '_AM_XOONIPS_POLICY_RANKING_DESC', 'Policy settings for the access rankings.' );
// >> account policies
define( '_AM_XOONIPS_POLICY_ACCOUNT_REGISTER_USER_TITLE', 'User Registration Policies' );
define( '_AM_XOONIPS_POLICY_ACCOUNT_ACTIVATE_USER_TITLE', 'Activation type' );
define( '_AM_XOONIPS_POLICY_ACCOUNT_ACTIVATE_USER_DESC', 'Select activation type of newly registered users.' );
define( '_AM_XOONIPS_POLICY_ACCOUNT_ACTIVATE_USER_USER', 'Requires activation by user (recommended)' );
define( '_AM_XOONIPS_POLICY_ACCOUNT_ACTIVATE_USER_AUTO', 'Activate automatically' );
define( '_AM_XOONIPS_POLICY_ACCOUNT_ACTIVATE_USER_ADMIN', 'Activation by administrators' );
define( '_AM_XOONIPS_POLICY_ACCOUNT_CERTIFY_USER_TITLE', 'Ceritification type' );
define( '_AM_XOONIPS_POLICY_ACCOUNT_CERTIFY_USER_DESC', 'The user account have to certify for using XooNIps. Select ceritification type of activated users.' );
define( '_AM_XOONIPS_POLICY_ACCOUNT_CERTIFY_USER_MANUAL', 'Certification by moderators' );
define( '_AM_XOONIPS_POLICY_ACCOUNT_CERTIFY_USER_AUTO', 'Certify automatically' );
define( '_AM_XOONIPS_POLICY_ACCOUNT_INFO_REQUIREMENT_TITLE', 'Require fields in the profile editing form' );
define( '_AM_XOONIPS_POLICY_ACCOUNT_INITIAL_VALUES_TITLE', 'Initial properties of newly registered users' );
define( '_AM_XOONIPS_POLICY_ACCOUNT_INITIAL_MAX_ITEM_DESC', 'Set the maximum number of registration items in the private area.' );
define( '_AM_XOONIPS_POLICY_ACCOUNT_INITIAL_MAX_INDEX_DESC', 'Set the maximum number of registration indexes in the private area.' );
define( '_AM_XOONIPS_POLICY_ACCOUNT_INITIAL_MAX_DISK_DESC', 'Set the maximum storage size in the private area. The floating-point number will accept in this field.' );
// >> group policies
define( '_AM_XOONIPS_POLICY_GROUP_INITIAL_VALUES_TITLE', 'Initial properties of newly created groups' );
define( '_AM_XOONIPS_POLICY_GROUP_INITIAL_MAX_ITEM_DESC', 'Set the maximum number of registration items in the group area.' );
define( '_AM_XOONIPS_POLICY_GROUP_INITIAL_MAX_INDEX_DESC', 'Set the maximum number of registration indexes in the group area.' );
define( '_AM_XOONIPS_POLICY_GROUP_INITIAL_MAX_DISK_DESC', 'Set the maximum storage size in the group area. The floating-point number will accept in this field.' );
// >> item policies
define( '_AM_XOONIPS_POLICY_ITEM_PUBLIC_TITLE', 'Item Publication' );
define( '_AM_XOONIPS_POLICY_ITEM_PUBLIC_DESC', 'Policy settings for the item publication.' );
define( '_AM_XOONIPS_POLICY_ITEM_PUBLIC_MAIN_TITLE', 'Item Publication Policies' );
define( '_AM_XOONIPS_POLICY_ITEM_PUBLIC_CERTIFY_ITEM_TITLE', 'Certification type' );
define( '_AM_XOONIPS_POLICY_ITEM_PUBLIC_CERTIFY_ITEM_DESC', 'The certification is neccessary to open the item to the public. Select the certification type of the item publication.' );
define( '_AM_XOONIPS_POLICY_ITEM_PUBLIC_CERTIFY_ITEM_MANUAL', 'Certification by moderators' );
define( '_AM_XOONIPS_POLICY_ITEM_PUBLIC_CERTIFY_ITEM_AUTO', 'Certify automatically' );
define( '_AM_XOONIPS_POLICY_ITEM_PUBLIC_TARGET_USER_TITLE', 'Who can access to the public area?' );
define( '_AM_XOONIPS_POLICY_ITEM_PUBLIC_TARGET_USER_DESC', 'Select user type to access to the public area.' );
define( '_AM_XOONIPS_POLICY_ITEM_PUBLIC_TARGET_USER_PLATFORM', 'Registered user only' );
define( '_AM_XOONIPS_POLICY_ITEM_PUBLIC_TARGET_USER_ALL', 'All users (including the guest user)' );
define( '_AM_XOONIPS_POLICY_ITEM_PUBLIC_OTHER_TITLE', 'Related Other Policies' );
define( '_AM_XOONIPS_POLICY_ITEM_PUBLIC_DOWNLOAD_FILE_TITLE', 'Download file type' );
define( '_AM_XOONIPS_POLICY_ITEM_PUBLIC_DOWNLOAD_FILE_DESC', 'Select the download file type of the attachements.' );
define( '_AM_XOONIPS_POLICY_ITEM_PUBLIC_DOWNLOAD_FILE_ZIP', 'Zipped with meta-informations' );
define( '_AM_XOONIPS_POLICY_ITEM_PUBLIC_DOWNLOAD_FILE_PLAIN', 'Original file' );
define( '_AM_XOONIPS_POLICY_ITEM_PUBLIC_ITEM_SHOW_TITLE', 'Can users select the publication list from all public items?' );
define( '_AM_XOONIPS_POLICY_ITEM_PUBLIC_ITEM_SHOW_DESC', 'If chose "NO", they can select from their items only.' );
define( '_AM_XOONIPS_POLICY_ITEM_TYPE_TITLE', 'Item Types' );
define( '_AM_XOONIPS_POLICY_ITEM_TYPE_DESC', 'Policy settings for the item types.' );
define( '_AM_XOONIPS_POLICY_ITEM_TYPE_VIEWCONFIG_TITLE', 'Display Setting' );
define( '_AM_XOONIPS_POLICY_ITEM_TYPE_VIEWCONFIG_DESC', 'Please input the integer of the one or more for the display order.' );
define( '_AM_XOONIPS_POLICY_ITEM_TYPE_EMPTY', 'No Item Types found' );
define( '_AM_XOONIPS_POLICY_ITEM_IMEXPORT_TITLE', 'Import / Export' );
define( '_AM_XOONIPS_POLICY_ITEM_IMEXPORT_DESC', 'Policy settings for the item importing and exporting.' );
define( '_AM_XOONIPS_POLICY_ITEM_IMEXPORT_EXPORT_TITLE', 'Export' );
define( '_AM_XOONIPS_POLICY_ITEM_IMEXPORT_IMPORT_TITLE', 'Import' );
define( '_AM_XOONIPS_POLICY_ITEM_IMEXPORT_EXPORT_ENABLED_TITLE', 'Export enabled' );
define( '_AM_XOONIPS_POLICY_ITEM_IMEXPORT_EXPORT_ENABLED_DESC', 'If chose "YES", the registered user can export self created items.<br /><br />Note : The moderators can always export all items regardless of this setting.' );
define( '_AM_XOONIPS_POLICY_ITEM_IMEXPORT_EXPORT_ATTACHMENT_TITLE', 'Export attachments' );
define( '_AM_XOONIPS_POLICY_ITEM_IMEXPORT_EXPORT_ATTACHMENT_DESC', 'If chose "YES", the user can export attachment files.' );
define( '_AM_XOONIPS_POLICY_ITEM_IMEXPORT_IMPORT_ENABLED_TITLE', 'Import enabled' );
define( '_AM_XOONIPS_POLICY_ITEM_IMEXPORT_IMPORT_ENABLED_DESC', 'If chose "YES", the registered user can import data into private area. <br /><br />Note : The moderators can always import data into all areas regardless of this setting.' );
define( '_AM_XOONIPS_POLICY_ITEM_COMMENT_TITLE', 'Item Comment' );
define( '_AM_XOONIPS_POLICY_ITEM_COMMENT_DESC', 'Comment settings for the item.<br />This function depends on d3forum module. You have to install d3forum module and create forum before setting these options.' );
define( '_AM_XOONIPS_POLICY_ITEM_COMMENT_DIRNAME_TITLE', 'Directory setting' );
define( '_AM_XOONIPS_POLICY_ITEM_COMMENT_DIRNAME_DESC', 'Set the directory name of d3forum used by comment function.' );
define( '_AM_XOONIPS_POLICY_ITEM_COMMENT_DIRNAME_NOTFOUND', 'Stored d3forum directory not found' );
define( '_AM_XOONIPS_POLICY_ITEM_COMMENT_FORUMID_TITLE', 'Forum ID setting' );
define( '_AM_XOONIPS_POLICY_ITEM_COMMENT_FORUMID_DESC', 'Set the forum ID made with d3forum.' );
define( '_AM_XOONIPS_POLICY_ITEM_COMMENT_FORUMID_NOTFOUND', 'Stored forum ID not found' );

// >> moderator privileges policies
define( '_AM_XOONIPS_POLICY_MODERATOR_MODIFY_TITLE', 'Accept to modify any user\'s items' );
define( '_AM_XOONIPS_POLICY_MODERATOR_MODIFY_DESC', 'If chose "YES", the moderators can modify any user\'s created items.' );
// >> positions configuration
define( '_AM_XOONIPS_POLICY_POSITION_MODIFY_TITLE', 'Modify Positions' );
define( '_AM_XOONIPS_POLICY_POSITION_ADD_TITLE', 'Add New Position' );
// >> ranking configuration
define( '_AM_XOONIPS_POLICY_RANKING_BLOCK_TITLE', 'Block' );
define( '_AM_XOONIPS_POLICY_RANKING_NAME_TITLE', 'Ranking block' );
define( '_AM_XOONIPS_POLICY_RANKING_RANGE_DESC1', 'Show ' );
define( '_AM_XOONIPS_POLICY_RANKING_RANGE_DESC2', ' items in each rankings.' );
define( '_AM_XOONIPS_POLICY_RANKING_DAYS_TITLE', 'Calculation Days' );
define( '_AM_XOONIPS_POLICY_RANKING_DAYS_DESC1', 'If set \'ON\', the sum-file does not affect to access ranking.' );
define( '_AM_XOONIPS_POLICY_RANKING_DAYS_DESC2', 'Calculate based on last ' );
define( '_AM_XOONIPS_POLICY_RANKING_DAYS_DESC3', ' days log.' );

// site maintenance
define( '_AM_XOONIPS_MAINTENANCE_ACCOUNT_TITLE', 'User Management' );
define( '_AM_XOONIPS_MAINTENANCE_ACCOUNT_DESC', 'Management for the User informations' );
define( '_AM_XOONIPS_MAINTENANCE_ITEM_TITLE', 'Item Management' );
define( '_AM_XOONIPS_MAINTENANCE_ITEM_DESC', 'Operations for item management. Please use carefully, because these operations have a large influence on the XooNIps contents.' );
define( '_AM_XOONIPS_MAINTENANCE_POSITION_TITLE', 'User List' );
define( '_AM_XOONIPS_MAINTENANCE_POSITION_DESC', 'Customize the display order for the \'User List\' view. If negative value is entered in \'Weight\' field then the user will disappear from the \'User List\' view.' );
define( '_AM_XOONIPS_MAINTENANCE_RANKING_TITLE', 'Access Rankings' );
define( '_AM_XOONIPS_MAINTENANCE_RANKING_DESC', 'Management for the SUM of Access Rankings.' );
define( '_AM_XOONIPS_MAINTENANCE_FILESEARCH_TITLE', 'File Search' );
define( '_AM_XOONIPS_MAINTENANCE_FILESEARCH_DESC', 'Management for the File Search Indexes.' );
define( '_AM_XOONIPS_MAINTENANCE_OAIPMH_TITLE', 'OAI-PMH' );
define( '_AM_XOONIPS_MAINTENANCE_OAIPMH_DESC', 'Management for the harvest results and harvester excecution.' );
// >> account management
define( '_AM_XOONIPS_MAINTENANCE_ACCOUNT_ADD_TITLE', 'Register New User' );
define( '_AM_XOONIPS_MAINTENANCE_ACCOUNT_MODIFY_TITLE', 'Modify User Information' );
define( '_AM_XOONIPS_MAINTENANCE_ACCOUNT_EMPTY', 'No users found.' );
define( '_AM_XOONIPS_MAINTENANCE_ACCOUNT_PAGENAVI_FORMAT', '%1$d - %2$d of %3$d Users' );
define( '_AM_XOONIPS_MAINTENANCE_ACCOUNT_ACONFIRM_TITLE', 'User Activate Confirmation' );
define( '_AM_XOONIPS_MAINTENANCE_ACCOUNT_DCONFIRM_TITLE', 'User Delete Confirmation' );
define( '_AM_XOONIPS_MAINTENANCE_ACCOUNT_DCONFIRM_MSG_IGNORE_USER', 'Please remove System Administrator or Moderator or Group Administrator user privileges' );
define( '_AM_XOONIPS_MAINTENANCE_ACCOUNT_DCONFIRM_MSG_ITEM_HANDOVER', 'Please transfer Public and/or Group items before User Deletion' );
define( '_AM_XOONIPS_MAINTENANCE_ACCOUNT_DELETE_MSG_SUCCESS', 'User has been deleted' );
// >> item management
define( '_AM_XOONIPS_MAINTENANCE_ITEM_LABEL_INDEX', 'Index' );
define( '_AM_XOONIPS_MAINTENANCE_ITEM_LABEL_SUCCEED', 'Succeed' );
define( '_AM_XOONIPS_MAINTENANCE_ITEM_LABEL_FAILED', 'Failed' );
define( '_AM_XOONIPS_MAINTENANCE_ITEM_LABEL_UNCERTIFIED', 'Not certified' );
define( '_AM_XOONIPS_MAINTENANCE_ITEM_LABEL_ALLUSERS', 'All Users' );
define( '_AM_XOONIPS_MAINTENANCE_ITEM_MSG_SELECT_INDEX', 'Please select indexes at first.' );
define( '_AM_XOONIPS_MAINTENANCE_ITEM_MSG_SELECT_USER', 'Please select user.' );
define( '_AM_XOONIPS_MAINTENANCE_ITEM_INDEX_EMPTY', 'No indexes are selected.' );
define( '_AM_XOONIPS_MAINTENANCE_ITEM_WITHDRAW_TITLE', 'Withdraw Items' );
define( '_AM_XOONIPS_MAINTENANCE_ITEM_WITHDRAW_DESC', 'Select indexes below and push Withdraw button. The all existing items of indexes selected will be withdrawn.' );
define( '_AM_XOONIPS_MAINTENANCE_ITEM_WITHDRAW_LABEL_WITHDRAW', 'Withdraw' );
define( '_AM_XOONIPS_MAINTENANCE_ITEM_WITHDRAW_CONFIRM', 'The all items of selected indexes will be withdrawn.' );
define( '_AM_XOONIPS_MAINTENANCE_ITEM_WUPDATE_TITLE', 'Results' );
define( '_AM_XOONIPS_MAINTENANCE_ITEM_WUPDATE_DESC', 'The items of not certified status ware not modified.' );
define( '_AM_XOONIPS_MAINTENANCE_ITEM_DELETE_TITLE', 'Delete Items' );
define( '_AM_XOONIPS_MAINTENANCE_ITEM_DELETE_DESC', 'Select indexes below and plush DELETE button. The all existing items of indexes selected will be deleted.' );
define( '_AM_XOONIPS_MAINTENANCE_ITEM_DELETE_CONFIRM', 'The all items of selected indexes will be deleted.' );
define( '_AM_XOONIPS_MAINTENANCE_ITEM_DUPDATE_TITLE', 'Results' );
define( '_AM_XOONIPS_MAINTENANCE_ITEM_TRANSFER_TITLE', 'Transfer items' );

// >> position (user list) maintenance
define( '_AM_XOONIPS_MAINTENANCE_POSITION_USER_TITLE', 'Position [ User Name ]' );
define( '_AM_XOONIPS_MAINTENANCE_POSITION_EMPTY', 'No users found. Everyone doesn\'t choose their position.' );
// >> ranking file maintenance
define( '_AM_XOONIPS_MAINTENANCE_RANKING_FILE_TITLE', 'Ranking SUM file' );
define( '_AM_XOONIPS_MAINTENANCE_RANKING_DOWNLOAD_TITLE', 'Download' );
define( '_AM_XOONIPS_MAINTENANCE_RANKING_DOWNLOAD_DESC', 'Get the access ranking SUM file.' );
 define( '_AM_XOONIPS_MAINTENANCE_RANKING_UPLOAD_TITLE', 'Upload' );
define( '_AM_XOONIPS_MAINTENANCE_RANKING_UPLOAD_DESC', 'Set the access ranking SUM file.' );
define( '_AM_XOONIPS_MAINTENANCE_RANKING_CLEAR_TITLE', 'Clear SUM' );
define( '_AM_XOONIPS_MAINTENANCE_RANKING_CLEAR_DESC', 'Clear existing SUM data' );
define( '_AM_XOONIPS_MAINTENANCE_RANKING_CLEAR_MESSAGE', 'SUM exists ( from %s to %s )' );
define( '_AM_XOONIPS_MAINTENANCE_RANKING_CLEAR_EMPTY', 'No SUM.' );
define( '_AM_XOONIPS_MAINTENANCE_RANKING_NOTE', 'Note : The ranking data are calculates from event logs. If you want to delete event logs, please download SUM file before deletion event logs.' );
define( '_AM_XOONIPS_MAINTENANCE_RANKING_LOCKED', 'Now calculating. Please retry after few seconds.' );
// >> file search index maintenance
define( '_AM_XOONIPS_MAINTENANCE_FILESEARCH_LABEL_PLUGIN', 'Plugins' );
define( '_AM_XOONIPS_MAINTENANCE_FILESEARCH_LABEL_MIMETYPE', 'MIME Type' );
define( '_AM_XOONIPS_MAINTENANCE_FILESEARCH_LABEL_SUFFIX', 'Suffix' );
define( '_AM_XOONIPS_MAINTENANCE_FILESEARCH_LABEL_VERSION', 'Version' );
define( '_AM_XOONIPS_MAINTENANCE_FILESEARCH_LABEL_RESCAN', 'Rescan' );
define( '_AM_XOONIPS_MAINTENANCE_FILESEARCH_LABEL_RESCANNING', 'Rescanning Now...' );
define( '_AM_XOONIPS_MAINTENANCE_FILESEARCH_PLUGINS_TITLE', 'File Search Plugins' );
define( '_AM_XOONIPS_MAINTENANCE_FILESEARCH_PLUGINS_EMPTY', 'No plugins found.' );
define( '_AM_XOONIPS_MAINTENANCE_FILESEARCH_RESCAN_LABEL_FILECOUNT', 'Registered Files' );
define( '_AM_XOONIPS_MAINTENANCE_FILESEARCH_RESCAN_TITLE', 'Rescan All Files');
define( '_AM_XOONIPS_MAINTENANCE_FILESEARCH_RESCAN_INFO_TITLE', 'Update File Information' );
define( '_AM_XOONIPS_MAINTENANCE_FILESEARCH_RESCAN_INFO_DESC', 'Rescan all files for updating file informations (MIME Type and Thumbnail)' );
define( '_AM_XOONIPS_MAINTENANCE_FILESEARCH_RESCAN_INDEX_TITLE', 'Update File Search Index' );
define( '_AM_XOONIPS_MAINTENANCE_FILESEARCH_RESCAN_INDEX_DESC', 'Rescan all files for rebuilding full-text search indexes.' );

// >> oaipmh maintenance
define( '_AM_XOONIPS_MAINTENANCE_OAIPMH_LABEL_LASTRESULT', 'Result' );
define( '_AM_XOONIPS_MAINTENANCE_OAIPMH_RESULTS_TITLE', 'Recent Results' );
define( '_AM_XOONIPS_MAINTENANCE_OAIPMH_RESULTS_EMPTY', 'No Results found.' );
define( '_AM_XOONIPS_MAINTENANCE_OAIPMH_CONFIGURE_TITLE', 'Repository URLs' );
define( '_AM_XOONIPS_MAINTENANCE_OAIPMH_CONFIGURE_DESC', 'Go to OAI-PMH Configurations' );
define( '_AM_XOONIPS_MAINTENANCE_OAIPMH_HARVEST_TITLE', 'Harvest' );
define( '_AM_XOONIPS_MAINTENANCE_OAIPMH_HARVEST_DESC', 'If you want to harvest metadata from configured repositories, push following button.' );
define( '_AM_XOONIPS_MAINTENANCE_OAIPMH_LABEL_HARVEST', 'Harvest Now' );

define( "_AM_XOONIPS_MAINTENANCE_TRANSFER_ADMIN_ITEM_SELECT_CHECK", "Check" );
define( "_AM_XOONIPS_MAINTENANCE_TRANSFER_ADMIN_ITEM_SELECT_ITEM_ID", "ID" );
define( "_AM_XOONIPS_MAINTENANCE_TRANSFER_ADMIN_ITEM_SELECT_ITEM_TYPE", "Item type" );
define( "_AM_XOONIPS_MAINTENANCE_TRANSFER_ADMIN_ITEM_SELECT_TITLE", "Title" );
define( "_AM_XOONIPS_MAINTENANCE_TRANSFER_ADMIN_ITEM_SELECT_FROM", "From" );
define( "_AM_XOONIPS_MAINTENANCE_TRANSFER_ADMIN_ITEM_SELECT_TO", "To" );
define( "_AM_XOONIPS_MAINTENANCE_TRANSFER_ADMIN_ITEM_SELECT_SUBMIT", "Transfer" );
define( "_AM_XOONIPS_MAINTENANCE_TRANSFER_ADMIN_ITEM_SELECT_CAN_NOT_TRANSFER_BECAUSE_OF_ITEM_LOCK", "Can not transfer item(%d) because it is locked." );
define( "_AM_XOONIPS_MAINTENANCE_TRANSFER_ADMIN_ITEM_SELECT_CAN_NOT_TRANSFER_BECAUSE_OF_CHILD_OF_OTHER_ITEM", "Can not transfer item(%d) because it is refered other items." );
define( "_AM_XOONIPS_MAINTENANCE_TRANSFER_ADMIN_ITEM_SELECT_NO_ITEM", "No items" );

define( "_AM_XOONIPS_MAINTENANCE_TRANSFER_ADMIN_ITEM_LIST_PAGE_TITLE", "Transfer confirmation" );
define( "_AM_XOONIPS_MAINTENANCE_TRANSFER_ADMIN_ITEM_LIST_MESSAGE", "Following items are transfered. Ready to proceed ?" );
define( "_AM_XOONIPS_MAINTENANCE_TRANSFER_ADMIN_ITEM_LIST_SUBSCRIBE_USER_TO_GROUP", "Transferee %2\$s is subscribed to group %1\$s" );
define( "_AM_XOONIPS_MAINTENANCE_TRANSFER_ADMIN_ITEM_LIST_LIMIT_CHECK_OUT_OF_BOUNDS", "Can not transfer items because number of items or storage size of transferee is out of bounds." );
define( "_AM_XOONIPS_MAINTENANCE_TRANSFER_ADMIN_ITEM_LIST_FROM", "From" );
define( "_AM_XOONIPS_MAINTENANCE_TRANSFER_ADMIN_ITEM_LIST_USER_NAME", "User name:" );
define( "_AM_XOONIPS_MAINTENANCE_TRANSFER_ADMIN_ITEM_LIST_INDEX_NAME", "Index name:" );
define( "_AM_XOONIPS_MAINTENANCE_TRANSFER_ADMIN_ITEM_LIST_ITEM_ID", "ID" );
define( "_AM_XOONIPS_MAINTENANCE_TRANSFER_ADMIN_ITEM_LIST_ITEM_TYPE", "Item type" );
define( "_AM_XOONIPS_MAINTENANCE_TRANSFER_ADMIN_ITEM_LIST_TITLE", "Title" );
define( "_AM_XOONIPS_MAINTENANCE_TRANSFER_ADMIN_ITEM_LIST_TO", "To" );
define( "_AM_XOONIPS_MAINTENANCE_TRANSFER_ADMIN_ITEM_LIST_CANCEL", "Abort" );
define( "_AM_XOONIPS_MAINTENANCE_TRANSFER_ADMIN_ITEM_LIST_SUBMIT", "Transfer" );
define( "_AM_XOONIPS_MAINTENANCE_TRANSFER_ADMIN_ITEM_LIST_CAN_NOT_TRANSFER", "Can not transfer item(%d)." );
define( "_AM_XOONIPS_MAINTENANCE_TRANSFER_ADMIN_ITEM_LIST_CAN_NOT_TRANSFER_REQUEST_CERTIFY_ITEM", "Can not transfer certify required item(%d)." );
define( "_AM_XOONIPS_MAINTENANCE_TRANSFER_ADMIN_ITEM_LIST_CAN_NOT_TRANSFER_REQUEST_TRANSFER_ITEM", "Can not transfer transfer required item(%d)." );
define( "_AM_XOONIPS_MAINTENANCE_TRANSFER_ADMIN_ITEM_LIST_CAN_NOT_TRANSFER_HAVE_ANOTHER_PARENT_ITEM", "Can not transfer item(%d) referred from other items." );
define( "_AM_XOONIPS_MAINTENANCE_TRANSFER_ADMIN_ITEM_LIST_CAN_NOT_TRANSFER_CHILD_REQUEST_CERTIFY_ITEM", "Can not transfer item(%d) that its child item is certify required.");
define( "_AM_XOONIPS_MAINTENANCE_TRANSFER_ADMIN_ITEM_LIST_CAN_NOT_TRANSFER_CHILD_REQUEST_TRANSFER_ITEM", "Can not transfer item(%d) that its child item is transfer required.");
define( "_AM_XOONIPS_MAINTENANCE_TRANSFER_ADMIN_ITEM_LIST_NO_ITEMS_SELECTED", "No items selected");

define( "_AM_XOONIPS_MAINTENANCE_TRANSFER_ITEM_ERROR", "Failed in accept transfer item");
define( "_AM_XOONIPS_MAINTENANCE_TRANSFER_ITEM_ERROR_ITEM_NUMBER_EXCEEDS", "Can not transfer items because number of items exceeds.");
define( "_AM_XOONIPS_MAINTENANCE_TRANSFER_ITEM_ERROR_ITEM_STORAGE_EXCEEDS", "Can not transfer items because storage size exceeds.");
define( "_AM_XOONIPS_MAINTENANCE_TRANSFER_ITEM_ERROR_BAD_SUBSCRIBE_GROUP", "Transferee is not subscribed groups.");
define( "_AM_XOONIPS_MAINTENANCE_TRANSFER_ITEM_ERROR_ONLY_1_USER", "Can not transfer items because there is only 1 user.");
define( "_AM_XOONIPS_MAINTENANCE_TRANSFER_ITEM_ERROR_NO_FROM_UID_SELECTED", "No transferer user selected");
define( "_AM_XOONIPS_MAINTENANCE_TRANSFER_ITEM_ERROR_NO_TO_UID_SELECTED", "No transferee user selected");
define( "_AM_XOONIPS_MAINTENANCE_TRANSFER_ITEM_ERROR_NO_FROM_INDEX_ID_SELECTED", "No transferer index selected");
define( "_AM_XOONIPS_MAINTENANCE_TRANSFER_ITEM_ERROR_NO_TO_INDEX_ID_SELECTED", "No transferee index selected");
define( "_AM_XOONIPS_MAINTENANCE_TRANSFER_ITEM_COMPLETE", "Transfer item completed.");
?>
